@@ -1673,6 +1673,8 @@ egg_xfont_selector_get_xlfd_field (const gchar *fontname,
   
   if (t1 != t2)
     {
+      char *p;
+      
       /* Check we don't overflow the buffer */
       len = (long) t2 - (long) t1;
       if (len > XLFD_MAX_FIELD_LEN - 1)
@@ -1681,7 +1683,12 @@ egg_xfont_selector_get_xlfd_field (const gchar *fontname,
       buffer[len] = 0;
 
       /* Convert to lower case. */
-      g_ascii_strdown (buffer, -1);
+      p = buffer;
+      while (*p)
+        {
+          *p = g_ascii_tolower (*p);
+          ++p;
+        }
     }
   else
     strcpy(buffer, "(nil)");
@@ -1694,10 +1701,22 @@ egg_xfont_selector_finalize (GObject *object)
 {
   GObjectClass *parent_class;
   EggXFontSelector *sel;
-  
+  EggXFontFilter *filter;
+  gint prop;
+
   sel = EGG_XFONT_SELECTOR (object);
   parent_class = g_type_class_ref (g_type_parent (G_OBJECT_TYPE (object)));
 
+  /* Clear the filter data. */
+  filter = &sel->filters[EGG_XFONT_FILTER_BASE];
+  
+  for (prop = 0; prop < EGG_NUM_FONT_PROPERTIES; prop++)
+    {
+      g_free(filter->property_filters[prop]);
+      filter->property_filters[prop] = NULL;
+      filter->property_nfilters[prop] = 0;
+    }
+  
   g_free (sel->filtered_font_index);
   g_free (sel->size_options_map);
 
@@ -1712,4 +1731,3 @@ egg_xfont_selector_finalize (GObject *object)
 
   g_type_class_unref (parent_class);
 }
-
